<?php

namespace Drupal\dppca\Attribute;

use Drupal\Component\Plugin\Attribute\Plugin;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Defines a DPPCA task attribute object.
 *
 * Plugin Namespace: Plugin\DPPCA.
 */
#[\Attribute(\Attribute::TARGET_CLASS)]
class DppcaTask extends Plugin {

  /**
   * Constructs a DPPCA task attribute.
   *
   * @param string $id
   *   The plugin ID.
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup $label
   *   The human-readable name.
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup $category
   *   The human-readable category.
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup $description
   *   The description of the task.
   * @param \Drupal\dppca\Attribute\DppcaTaskRequire[] $require
   *   A list of required DPPCA tasks.
   */
  public function __construct(
    public readonly string $id,
    public readonly TranslatableMarkup $label,
    public readonly TranslatableMarkup $category,
    public readonly TranslatableMarkup $description,
    public readonly array $require = [],
  ) {}

}
