<?php

namespace Drupal\dppca\Attribute;

use Drupal\Component\Plugin\Attribute\Plugin;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Defines a suggested module that provides support for a required DPPCA tasks.
 */
#[\Attribute(\Attribute::TARGET_CLASS)]
class DppcaTaskModule extends Plugin {

  /**
   * Constructs a DPPCA suggested module attribute.
   *
   * @param string $id
   *   The module machine name.
   * @param \Drupal\Core\StringTranslation\TranslatableMarkup|null $label
   *   The human-readable name. Leave empty if that module is a dependency.
   */
  public function __construct(
    public readonly string $id,
    public readonly ?TranslatableMarkup $label = NULL,
  ) {}

  /**
   * Get a string containing the HTML link to this module.
   *
   * @return string
   *   The HTML link as a string.
   */
  public function __toString(): string {
    return '<a href="https://www.drupal.org/project/' . $this->id . '">' . (string) ($this->label ?? $this->id) . '</a>';
  }

}
