<?php

namespace Drupal\dppca\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\dppca\Config;
use Drupal\dppca\DppcaTaskPluginManager;
use Drupal\dppca\Storage;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Provides the report of the audit as a rendered page.
 */
class DppcaController extends ControllerBase {

  /**
   * The module's config.
   *
   * @var \Drupal\dppca\Config
   */
  protected Config $config;

  /**
   * The module's storage.
   *
   * @var \Drupal\dppca\Storage
   */
  protected Storage $storage;

  /**
   * The plugin manager for DPPCA tasks.
   *
   * @var \Drupal\dppca\DppcaTaskPluginManager
   */
  protected DppcaTaskPluginManager $pluginManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): static {
    $instance = parent::create($container);
    $instance->config = $container->get('dppca.config');
    $instance->storage = $container->get('dppca.storage');
    $instance->pluginManager = $container->get('plugin.manager.dppca');
    return $instance;
  }

  /**
   * Callback to render the page.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The current request.
   *
   * @return array
   *   The render array for the report.
   */
  public function overview(Request $request): array {
    $build = [];
    foreach ($this->pluginManager->generateTree() as $id => $children) {
      /** @var \Drupal\dppca\DppcaTaskInterface $plugin */
      $plugin = $this->pluginManager->createInstance($id);
      $build[] = $plugin->build($children);
    }
    return $build;
  }

}
