<?php

namespace Drupal\dppca\Plugin\DPPCA;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\dppca\Attribute\DppcaTask;
use Drupal\dppca\Attribute\DppcaTaskModule;
use Drupal\dppca\Attribute\DppcaTaskRequire;
use Drupal\dppca\DppcaTaskBasePlugin;

/**
 * Provides DPPCA task plugin to manage personally identifiable data.
 */
#[DppcaTask(
  id: 'pii',
  label: new TranslatableMarkup('Personally identifiable data'),
  category: new TranslatableMarkup('Data protection'),
  description: new TranslatableMarkup('Manage personally identifiable data'),
  require: [
    new DppcaTaskRequire(
      id: 'mark_pii',
      label: new TranslatableMarkup('Identify personally identifiable data'),
      modules: [
        new DppcaTaskModule(
          id: 'gdpr',
          label: new TranslatableMarkup('General Data Protection Regulation'),
        ),
      ],
    ),
    new DppcaTaskRequire(
      id: 'encrypt_pii',
      label: new TranslatableMarkup('Encrypt personally identifiable data'),
      modules: [
        new DppcaTaskModule(
          id: 'encrypt',
          label: new TranslatableMarkup('Encrypt'),
        ),
      ],
    ),
    new DppcaTaskRequire(
      id: 'report_pii',
      label: new TranslatableMarkup('Report about personally identifiable data'),
      modules: [
        new DppcaTaskModule(
          id: 'gdpr',
          label: new TranslatableMarkup('General Data Protection Regulation'),
        ),
      ],
    ),
    new DppcaTaskRequire(
      id: 'delete_pii',
      label: new TranslatableMarkup('Delete personally identifiable data'),
      modules: [
        new DppcaTaskModule(
          id: 'gdpr',
          label: new TranslatableMarkup('General Data Protection Regulation'),
        ),
      ],
    ),
  ],
)]
class Pii extends DppcaTaskBasePlugin {

}
