<?php

namespace Drupal\dppca;

use Drupal\Core\KeyValueStore\DatabaseStorage;
use Drupal\Core\KeyValueStore\KeyValueDatabaseFactory;

/**
 * Provides storage services for DPPCA results.
 */
class Storage {

  public const KEY_STATUS = 'status';

  public const STATUS_NEVER_SCANNED = -1;

  public const STATUS_OK = 1;

  public const STATUS_WARNING = 2;

  public const STATUS_ALERT = 3;

  /**
   * The database store.
   *
   * @var \Drupal\Core\KeyValueStore\DatabaseStorage
   */
  protected DatabaseStorage $store;

  /**
   * Constructs the storage service for DPPCA.
   *
   * @param \Drupal\Core\KeyValueStore\KeyValueDatabaseFactory $factory
   *   The key value database factory.
   */
  public function __construct(KeyValueDatabaseFactory $factory) {
    $store = $factory->get('dppca');
    if ($store instanceof DatabaseStorage) {
      $this->store = $store;
    }
  }

  /**
   * Set a value to the storage.
   *
   * @param string $pluginId
   *   The plugin ID.
   * @param string $key
   *   The key.
   * @param mixed $value
   *   The values.
   */
  protected function setValue(string $pluginId, string $key, mixed $value): void {
    $values = $this->store->get($pluginId, []);
    $values[$key] = $value;
    $this->store->set($pluginId, $values);
  }

  /**
   * Get a value from the storage.
   *
   * @param string $pluginId
   *   The plugin ID.
   * @param string $key
   *   The key.
   *
   * @return mixed
   *   The stored value for the given key of the plugin or NULL, if no value is
   *   available.
   */
  protected function getValue(string $pluginId, string $key): mixed {
    $values = $this->store->get($pluginId);
    return $values[$key] ?? NULL;
  }

  /**
   * Get the status of a plugin.
   *
   * @param string $pluginId
   *   The plugin ID.
   *
   * @return int
   *   The status as an integer value.
   */
  public function getStatus(string $pluginId): int {
    return 0;
  }

}
